==> libexplain-1.2.tar.gz: libexplain-1.2/test/getresuid/main.c <==
/*
 * libexplain - Explain errno values returned by libc functions
 * Copyright (C) 2012 Peter Miller
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 3 of the License, or (at your
 * option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <libexplain/ac/stdio.h>
#include <libexplain/ac/stdlib.h>
#include <libexplain/ac/unistd.h>

#include <libexplain/getresuid.h>
#include <libexplain/string_to_thing.h>
#include <libexplain/version_print.h>


static void
usage(void)
{
    fprintf(stderr, "Usage: test_getresuid <ruid> <euid> <suid>\n");
    fprintf(stderr, "       test_getresuid -V\n");
    exit(EXIT_FAILURE);
}


int
main(int argc, char **argv)
{
    uid_t           *ruid;
    uid_t           *euid;
    uid_t           *suid;

    for (;;)
    {
        int c = getopt(argc, argv, "V");
        if (c == EOF)
            break;
        switch (c)
        {
        case 'V':
            explain_version_print();
            return EXIT_SUCCESS;

        default:
            usage();
        }
    }
    if (optind + 3 != argc)
        usage();
    ruid = explain_string_to_pointer(argv[optind]);
    euid = explain_string_to_pointer(argv[optind + 1]);
    suid = explain_string_to_pointer(argv[optind + 2]);

    explain_getresuid_or_die(ruid, euid, suid);
    return EXIT_SUCCESS;
}


/* vim: set ts=8 sw=4 et : */

==> libexplain-1.3.tar.gz: libexplain-1.3/test/getresuid/main.c <==
/*
 * libexplain - Explain errno values returned by libc functions
 * Copyright (C) 2012, 2013 Peter Miller
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 3 of the License, or (at your
 * option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <libexplain/ac/stdio.h>
#include <libexplain/ac/stdlib.h>
#include <libexplain/ac/unistd.h>

#include <libexplain/getresuid.h>
#include <libexplain/string_to_thing.h>
#include <libexplain/version_print.h>


static void
usage(void)
{
    fprintf(stderr, "Usage: test_getresuid <ruid> <euid> <suid>\n");
    fprintf(stderr, "       test_getresuid -V\n");
    exit(EXIT_FAILURE);
}


int
main(int argc, char **argv)
{
    uid_t           *ruid;
    uid_t           *euid;
    uid_t           *suid;

    for (;;)
    {
        int c = getopt(argc, argv, "V");
        if (c == EOF)
            break;
        switch (c)
        {
        case 'V':
            explain_version_print();
            return EXIT_SUCCESS;

        default:
            usage();
        }
    }
    if (optind + 3 != argc)
        usage();
    ruid = explain_parse_pointer_or_die(argv[optind]);
    euid = explain_parse_pointer_or_die(argv[optind + 1]);
    suid = explain_parse_pointer_or_die(argv[optind + 2]);

    explain_getresuid_or_die(ruid, euid, suid);
    return EXIT_SUCCESS;
}


/* vim: set ts=8 sw=4 et : */
